import React from 'react';
import ReactDOM from 'react-dom';
import {scaleSqrt, max} from 'd3'
import { useWorldAtlas } from './useWorldAtlas';
import { useGTD } from './useGTD';
import { Marks } from './Marks';

const width = 960;
const height = 500;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const GTD = useGTD();
  console.log(GTD);

  if (!worldAtlas || !GTD) {
    return <pre>Loading...</pre>;
  }

  const sizeValue = d => d.nwoundkill;
  const maxRadius = 13;
  
  const sizeScale = scaleSqrt()
  	.domain([0, max(GTD, sizeValue)])
  	.range([0, maxRadius])
  
  return (
    <svg width={width} height={height}>
      <Marks 
        worldAtlas={worldAtlas} 
        GTD ={GTD} 
        sizeScale={sizeScale} 
        sizeValue={sizeValue}/>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
